%%
%
% Basic Q learning in discrete case
%  http://mnemstudio.org/path-finding-q-learning-tutorial.htm
%
ccc;

%% Define Markov Decision Process (MDP)
ccc;
mdp = make_disc_mdp();

% plot things
plot_mdp_state(mdp);
plot_mdp_R(mdp);
plot_mdp_T(mdp);
plot_mdp_Q(mdp);

%% Evaluate Q learning 
maxiter = 1E3;
for iter = 1:maxiter
    % 1. select state (index)
    s = find(mnrnd(1, mdp.b) == 1);
    % 2. get traj and update Q matrx
    while 1
        % until it reaches terminate state
        if sum(mdp.ts == s) > 0
            break;
        end
        % 1. make move! 
        % find feasible movements 
        move_options = find(mdp.T(s, :) == 1);
        % permutate 'move_options' to handle all zero issues
        move_options = move_options(randperm(length(move_options)));
        move_Q = mdp.Q(s, move_options);
        % epsilon greedy (eps = 0.1) <== this part is usually done by actual experiment
        %  meaning that the trasition probabiity is not required 
        if rand > 0.4
            % find action based on "a = argmax_{a'} Q(s, a')"
            [~, temp_idx] = max(move_Q);
            a = move_options(temp_idx);
        else
            % ranndom action
            a = move_options(randi(length(move_options)));
        end
        % action indicates next state
        snext = a; 
        % 2. now we have (s, a, snext), update Q
        mdp.Q(s, a) = mdp.R(s, a) + mdp.gamma*max(mdp.Q(snext, :));
        % 3. update state
        s = snext; 
    end
    % plot for check
    % plot_mdp_Q(mdp); drawnow; pause;
end

plot_mdp_Q(mdp);

%%
close all;


