function plot_mdp_state(mdp)

figure();
hold on;

% plot connection (T)
for i = 1:mdp.nr_s
    for j = find(mdp.T(i, :) > 0)
        i_pos = mdp.s{i}.pos;
        j_pos = mdp.s{j}.pos;
        plot([i_pos(1) j_pos(1)], [i_pos(2) j_pos(2)], 'k-', 'LineWidth', 3);
    end
end
for i = 1:mdp.nr_s
    for j = find(mdp.T(i, :) > 0)
        i_pos = mdp.s{i}.pos;
        j_pos = mdp.s{j}.pos;
        if i < j
            str = sprintf('[%d->%d:%.2f]', i, j, mdp.T(i, j));
        else
            str = sprintf('\n[%d->%d:%.2f]', i, j,  mdp.T(i, j));
        end
        yoffset = 0.15;
        text((i_pos(1)+j_pos(1))/2, yoffset+(i_pos(2)+j_pos(2))/2 ...
            , str, 'FontSize', 10, 'HorizontalAlignment', 'center');
    end
end

% plot states
colors = lines(mdp.nr_s);
min_x = inf; min_y = inf;
max_x = -inf; max_y = -inf;
for i = 1:mdp.nr_s
    curr_x = mdp.s{i}.pos(1);
    curr_y = mdp.s{i}.pos(2);
    plot(curr_x, curr_y, 'o', 'MarkerSize', 15, 'LineWidth', 3, 'Color', colors(i, :), 'MarkerFaceColor', 'w');
    % check min max
    if curr_x > max_x
        max_x = curr_x;
    end
    if curr_x < min_x
        min_x = curr_x;
    end
    if curr_y > max_y
        max_y = curr_y;
    end
    if curr_y < min_y
        min_y = curr_y;
    end
end
for i = 1:mdp.nr_s
    text(mdp.s{i}.pos(1), mdp.s{i}.pos(2), mdp.s{i}.name ...
        , 'FontSize', 13, 'HorizontalAlignment', 'center');
end
hold off;
grid on;
title('MDP States', 'FontSize', 15);
x_w = max_x - min_x;
y_w = max_y - min_y;
min_w = min(x_w, y_w);
marg = min_w/10;
axis([min_x-marg max_x+marg min_y-marg max_y+marg]);
axis equal; % axis off;




